@@ -53,24 +53,7 @@ npindex <-
   }
 
 npindex.formula <-
-  function(bws,
-           data = NULL,
-           newdata = NULL,
-           ckertype = c("gaussian", "epanechnikov","uniform"), 
-           ckerorder = c(2,4,6,8),           
-           ...){
-
-    ckertype = match.arg(ckertype)
-
-    if(missing(ckerorder))
-      ckerorder = 2
-    else if (ckertype == "uniform")
-      warning("ignoring kernel order specified with uniform kernel type")
-    else {
-      kord = eval(formals()$ckerorder) 
-      if (!any(kord == ckerorder))
-        stop("ckerorder must be one of ", paste(kord,collapse=" "))
-    }
+  function(bws, data = NULL, newdata = NULL, ...){
 
     tt <- terms(bws)
     m <- match(c("formula", "data", "subset", "na.action"),
@@ -98,7 +81,7 @@ npindex.formula <-
     ev <-
     eval(parse(text=paste("npindex(txdat = txdat, tydat = tydat,",
                  ifelse(has.eval,paste("exdat = exdat,",ifelse(has.ey,"eydat = eydat,","")),""),
-                 "bws = bws, ckertype = ckertype, ckerorder = ckerorder,...)")))
+                 "bws = bws, ...)")))
     ev$rows.omit <- as.vector(attr(umf,"na.action"))
     ev$nobs.omit <- length(ev$rows.omit)
     ev
@@ -108,31 +91,10 @@ npindex.call <-
   function(bws, ...) {
     npindex(txdat = eval(bws$call[["xdat"]], environment(bws$call)),
             tydat = eval(bws$call[["ydat"]], environment(bws$call)),
-            bws = bws,
-            ckertype = bws$ckertype,
-            ckerorder = bws$ckerorder,
-            ...)
-  }
-
-npindex.default <- function(bws,
-                            txdat,
-                            tydat,
-                            ckertype = c("gaussian", "epanechnikov","uniform"), 
-                            ckerorder = c(2,4,6,8),           
-                            ...){
-
-  ckertype = match.arg(ckertype)
-
-  if(missing(ckerorder))
-    ckerorder = 2
-  else if (ckertype == "uniform")
-    warning("ignoring kernel order specified with uniform kernel type")
-  else {
-    kord = eval(formals()$ckerorder) 
-    if (!any(kord == ckerorder))
-      stop("ckerorder must be one of ", paste(kord,collapse=" "))
+            bws = bws, ...)
   }
 
+npindex.default <- function(bws, txdat, tydat, ...){
   sc.names <- names(sys.call())
 
   ## here we check to see if the function was called with tdat =
@@ -158,11 +120,11 @@ npindex.default <- function(bws,
                    ifelse(no.txdat, "", "txdat,"))
   ty.str <- ifelse(tydat.named, "ydat = tydat,",
                    ifelse(no.tydat, "", "tydat,"))
-
+  
   tbw <- eval(parse(text = paste("npindexbw(",
                       ifelse(bws.named,                             
                              paste(tx.str, ty.str,
-                                   "bws = bws, bandwidth.compute = FALSE, ckertype = ckertype, ckerorder = ckerorder,"),
+                                   "bws = bws, bandwidth.compute = FALSE,"),
                              paste(ifelse(no.bws, "", "bws,"), tx.str, ty.str)),
                       "call = mc, ...",")",sep="")))
 
@@ -200,10 +162,8 @@ npindex.default <- function(bws,
                        ifelse(no.tydat,"",",tydat"))
     }
   }
-
-  eval(parse(text=paste("npindex(bws = tbw", tx.str, ty.str, ", ckertype = ckertype, ckerorder = ckerorder,...)")))
-#  eval(parse(text=paste("npindex(bws = tbw", tx.str, ty.str, ",...)")))  
-
+  
+  eval(parse(text=paste("npindex(bws = tbw", tx.str, ty.str, ",...)")))
 }
 
 npindex.sibandwidth <-
@@ -215,26 +175,13 @@ npindex.sibandwidth <-
            gradients = FALSE,
            residuals = FALSE,
            errors = FALSE,
-           boot.num = 399,
-           ckertype = c("gaussian", "epanechnikov","uniform"), 
-           ckerorder = c(2,4,6,8),           
-           ...) {
-
-    ckertype = match.arg(ckertype)
-
-    if(missing(ckerorder))
-      ckerorder = 2
-    else if (ckertype == "uniform")
-      warning("ignoring kernel order specified with uniform kernel type")
-    else {
-      kord = eval(formals()$ckerorder) 
-      if (!any(kord == ckerorder))
-        stop("ckerorder must be one of ", paste(kord,collapse=" "))
-    }
+           boot.num = 399, ...) {
 
+  
     no.ex = missing(exdat)
     no.ey = missing(eydat)
     
+
     ## if no.ex then if !no.ey then ey and tx must match, to get
     ## oos errors alternatively if no.ey you get is errors if
     ## !no.ex then if !no.ey then ey and ex must match, to get
@@ -366,13 +313,13 @@ npindex.sibandwidth <-
                            tydat=tydat,
                            exdat=index.eval,
                            bws=bws$bw,
-                           ckertype=ckertype,
-                           ckerorder=ckerorder)$ksum/
+                           ckertype = bws$ckertype,
+                           ckerorder = bws$ckerorder)$ksum/
                              npksum(txdat=index,
                                     exdat=index.eval,
-                                    bws=bws$bw,
-                                    ckertype=ckertype,
-                                    ckerorder=ckerorder)$ksum
+                                    bws=bws$bw,                                    
+                                    ckertype = bws$ckertype,
+                                    ckerorder = bws$ckerorder)$ksum
 
       if(!no.ex & (no.ey | residuals)){
         ## want to evaluate on training data for in sample errors even
@@ -381,13 +328,13 @@ npindex.sibandwidth <-
         
         index.tmean <- npksum(txdat=index,
                               tydat=tydat,
-                              bws=bws$bw,
-                              ckertype=ckertype,
-                              ckerorder=ckerorder)$ksum/
+                              bws=bws$bw,                              
+                              ckertype = bws$ckertype,
+                              ckerorder = bws$ckerorder)$ksum/
                                 npksum(txdat=index,
-                                       bws=bws$bw,
-                                       ckertype=ckertype,
-                                       ckerorder=ckerorder)$ksum
+                                       bws=bws$bw,                                       
+                                       ckertype = bws$ckertype,
+                                       ckerorder = bws$ckerorder)$ksum
       }
 
     } else if(gradients==TRUE) {
@@ -395,10 +342,10 @@ npindex.sibandwidth <-
       model <- npreg(txdat=index,
                      tydat=tydat,
                      exdat=index.eval,
-                     bws=bws$bw,
+                     bws=bws$bw,                     
+                     ckertype = bws$ckertype,
+                     ckerorder = bws$ckerorder,
                      regtype="lc",
-                     ckertype=ckertype,
-                     ckerorder=ckerorder,
                      gradients=TRUE)
 
       index.mean <- model$mean
@@ -419,9 +366,9 @@ npindex.sibandwidth <-
         model <- npreg(txdat=index,
                        tydat=tydat,
                        bws=bws$bw,
+                       ckertype = bws$ckertype,
+                       ckerorder = bws$ckerorder,
                        regtype="lc",
-                       ckertype=ckertype,
-                       ckerorder=ckerorder,
                        gradients=TRUE)
 
         index.tmean <- model$mean
@@ -467,14 +414,13 @@ npindex.sibandwidth <-
       tyindex <- npksum(txdat = index,
                         tydat = rep(1,length(tydat)),
                         weights = W,
-                        bws = bws$bw,
-                        ckertype=ckertype,
-                        ckerorder=ckerorder)$ksum
+                        bws = bws$bw,                        
+                        ckertype = bws$ckertype,
+                        ckerorder = bws$ckerorder)$ksum
 
-      tindex <- npksum(txdat = index,
-                       bws = bws$bw,
-                       ckertype=ckertype,
-                       ckerorder=ckerorder)$ksum
+      tindex <- npksum(txdat = index, bws = bws$bw,                       
+                       ckertype = bws$ckertype,
+                       ckerorder = bws$ckerorder)$ksum
 
       ## Need to trap case where k-1=1... ksum will return a 1 D
       ## array, need a 1 x n matrix
@@ -548,9 +494,8 @@ npindex.sibandwidth <-
           tydat = tydat[indices],
           exdat = index.eval,
           bws = bws$bw,
-          ckertype=ckertype,
-          ckerorder=ckerorder,
-          )[c('mean','grad')]
+          ckertype = bws$ckertype,
+          ckerorder = bws$ckerorder)[c('mean','grad')]
 
         c(model$mean, model$grad, mean(model$grad))
       }
@@ -558,17 +503,13 @@ npindex.sibandwidth <-
     } else {
       boofun = function(data, indices){
         rindex = txdat[indices,] %*% bws$beta
-        npksum(txdat = rindex,
-               tydat = tydat[indices],
-               exdat = index.eval,
+        npksum(txdat = rindex, tydat = tydat[indices], exdat = index.eval,
                bws = bws$bw,
-               ckertype=ckertype,
-               ckerorder=ckerorder)$ksum/
-                 npksum(txdat = rindex,
-                        exdat = index.eval,
-                        bws=bws$bw,
-                        ckertype=ckertype,
-                        ckerorder=ckerorder)$ksum
+               ckertype = bws$ckertype,
+               ckerorder = bws$ckerorder)$ksum/
+                 npksum(txdat = rindex, exdat = index.eval, bws=bws$bw,                        
+                        ckertype = bws$ckertype,
+                        ckerorder = bws$ckerorder)$ksum
       }
     }
 
@@ -635,6 +576,7 @@ npindex.sibandwidth <-
       strres = ""
     }
 
+
     eval(parse(text=paste(
                  "singleindex(bws = bws, index = index.eval, mean = index.mean,",
                  ifelse(errors,"merr = index.merr,",""),
